@@ -16,6 +16,7 @@ end
 module JuliaCall
 
 const julia07 = VERSION > v"0.6.5"
+const julia14 = VERSION > v"1.3.2"
 
 if julia07
     using Pkg
@@ -47,7 +48,14 @@ else
 end
 
 function installed(name)
-    @static if julia07
+    @static if julia14
+        for p in values(Pkg.dependencies())
+            if p.name == name && p.is_direct_dep
+                return p.version
+            end
+        end
+        nothing
+    elseif julia07
         get(Pkg.installed(), name, nothing)
     else
         Pkg.installed(name)
@@ -192,7 +200,7 @@ function exists(x)
 end
 
 function eval_string(x)
-    Core.eval(Main, parse(x))
+    Core.eval(Main, parse(strip(x)))
 end
 
 function installed_package(pkg_name)
